#
# spec file for package python-HyperKitty
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without testsuite

# keep in sync with setup.py
%global django_min_version 3.2
%global django_max_version 4.3
%global django_mailman3_min_version 1.3.10
%global django_gravatar2_min_version 1.0.6
%global djangorestframework_min_version 3.0.0
%global robot_detection_min_version 0.3
%global pytz_min_version 2012
%global django_compressor_min_version 1.3
%global mailmanclient_min_version 3.3.3
# original this was >= 2.0.0, < 3.0 but overwritten by mistune3.patch
%global mistune_min_version 3.0
%global python_dateutil_min_version  2.0
%global networkx_min_version 2.0
%global django_haystack_min_version 2.8.0
%global django_extensions_min_version 1.3.7
%global flufl_lock_min_version 4.0
%global django_q_min_version 1.0.0

%global webapps_dir /srv/www/webapps

%global hyperkitty_pkgname   HyperKitty
%global lowname              hyperkitty

%global hyperkitty_basedir   %{webapps_dir}/mailman/hyperkitty
%global hyperkitty_localedir %{hyperkitty_basedir}/locale
%global hyperkitty_staticdir %{hyperkitty_basedir}/static

%global hyperkitty_etcdir    %{_sysconfdir}/hyperkitty
%global hyperkitty_libdir    %{_localstatedir}/lib/hyperkitty
%global hyperkitty_logdir    %{_localstatedir}/log/hyperkitty
%global hyperkitty_datadir   %{hyperkitty_libdir}/data

%global hyperkitty_services hyperkitty-qcluster.service hyperkitty-runjob-daily.service hyperkitty-runjob-daily.timer hyperkitty-runjob-hourly.service hyperkitty-runjob-hourly.timer hyperkitty-runjob-minutely.service hyperkitty-runjob-minutely.timer hyperkitty-runjob-monthly.service hyperkitty-runjob-monthly.timer hyperkitty-runjob-quarter-hourly.service hyperkitty-runjob-quarter-hourly.timer hyperkitty-runjob-weekly.service hyperkitty-runjob-weekly.timer hyperkitty-runjob-yearly.service hyperkitty-runjob-yearly.timer

# keep in sync with python-postorius/python-mailman-web
# Always only build one flavor: primary python for TW, python311 from the SLE15 python module for 15.x
%if 0%{?suse_version} >= 1550
%define pythons python3
%else
%{?sle15_python_module_pythons}
%endif
%global mypython %pythons
%global mypython_sitelib %{expand:%%{%{mypython}_sitelib}}
%global __mypython %{expand:%%{__%{mypython}}}
%define plainpython python

Name:           python-HyperKitty
Version:        1.3.9
Release:        1.1
Summary:        A web interface to access GNU Mailman v3 archives
License:        GPL-3.0-only
URL:            https://gitlab.com/mailman/hyperkitty
#
Source0:        https://gitlab.com/mailman/hyperkitty/-/releases/%{version}/downloads/hyperkitty-%{version}.tar.gz
Source1:        https://gitlab.com/mailman/hyperkitty/-/releases/%{version}/downloads/hyperkitty-%{version}.tar.gz.asc
Source2:        python-HyperKitty.keyring
Source3:        python-HyperKitty-rpmlintrc
#
Source10:       hyperkitty-manage.sh
Source12:       hyperkitty.uwsgi
#
Source20:       hyperkitty-qcluster.service
Source21:       hyperkitty-runjob.service
Source22:       hyperkitty-runjob.timer
#
Source30:       README.SUSE.md
#
# PATCH-FIX-OPENSUSE hyperkitty-settings.patch mcepl@suse.com
# hard-code locations of configuration files
Patch0:         hyperkitty-settings.patch
#
# PATCH-FIX-UPSTREAM gl-mr300-add-opengraph-metadata.patch gl#mailman/hyperkitty#300
Patch98:        gl-mr300-add-opengraph-metadata.patch
# PATCH-FIX-UPSTREAM gl-mr470-introduce-feed-filtering.patch gl#mailman/hyperkitty#470
Patch99:        gl-mr470-introduce-feed-filtering.patch
#
BuildRequires:  %{python_module Django >= %{django_min_version} with %python-Django < %{django_max_version}}
BuildRequires:  %{python_module Whoosh}
BuildRequires:  %{python_module django-compressor >= %{django_compressor_min_version}}
BuildRequires:  %{python_module django-debug-toolbar >= 2.2}
BuildRequires:  %{python_module django-extensions >= %{django_extensions_min_version}}
BuildRequires:  %{python_module django-gravatar2 >= %{django_gravatar2_min_version}}
BuildRequires:  %{python_module isort}
BuildRequires:  %{python_module mailmanclient >= %{mailmanclient_min_version}}
BuildRequires:  %{python_module mistune >= %{mistune_min_version}}
BuildRequires:  %{python_module pdm}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  %{python_module xapian-haystack >= 2.1.0}
BuildRequires:  acl
BuildRequires:  fdupes
BuildRequires:  openssl
BuildRequires:  python-rpm-macros
BuildRequires:  rsync
BuildRequires:  sassc
BuildRequires:  sudo
BuildArch:      noarch
%if 0%{?suse_version} >= 1550
# use the real python3 primary for rpm pythondistdeps.py
BuildRequires:  python3-packaging
%endif
# SECTION test requirements
BuildRequires:  %{python_module Whoosh >= 2.5.7}
BuildRequires:  %{python_module beautifulsoup4 >= 4.3.2}
BuildRequires:  %{python_module django-haystack >= %{django_haystack_min_version}}
BuildRequires:  %{python_module django-mailman3 >= %{django_mailman3_min_version}}
BuildRequires:  %{python_module django-q >= %{django_q_min_version}}
BuildRequires:  %{python_module djangorestframework >= %{djangorestframework_min_version}}
BuildRequires:  %{python_module elasticsearch}
BuildRequires:  %{python_module flufl.lock >= %{flufl_lock_min_version}}
BuildRequires:  %{python_module lxml}
BuildRequires:  %{python_module mistune >= %{mistune_min_version}}
BuildRequires:  %{python_module networkx >= %{networkx_min_version}}
BuildRequires:  %{python_module pytest-django}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module python-dateutil >= %{python_dateutil_min_version}}
BuildRequires:  %{python_module pytz >= %{pytz_min_version}}
BuildRequires:  %{python_module robot-detection >= %{robot_detection_min_version}}
# /SECTION

%description
A web interface to access GNU Mailman v3 archives.

%package -n %{hyperkitty_pkgname}
Summary:        A web interface to access GNU Mailman v3 archives
# important sync with
Requires:       (%{mypython}-Django >= %{django_min_version} with %{mypython}-Django < %{django_max_version})
Requires:       %{mypython}-django-compressor >= %{django_compressor_min_version}
Requires:       %{mypython}-django-debug-toolbar >= 2.2
Requires:       %{mypython}-django-extensions >= %{django_extensions_min_version}
Requires:       %{mypython}-django-gravatar2 >= %{django_gravatar2_min_version}
Requires:       %{mypython}-django-haystack >= 2.8.0
Requires:       %{mypython}-django-mailman3 >= %{django_mailman3_min_version}
Requires:       %{mypython}-django-q >= %{django_q_min_version}
Requires:       %{mypython}-djangorestframework >= %{djangorestframework_min_version}
Requires:       %{mypython}-flufl.lock >= %{flufl_lock_min_version}
Requires:       %{mypython}-mailmanclient >= %{mailmanclient_min_version}
Requires:       %{mypython}-mistune >= %{mistune_min_version}
Requires:       %{mypython}-networkx >= %{networkx_min_version}
Requires:       %{mypython}-python-dateutil >= %{python_dateutil_min_version}
Requires:       %{mypython}-pytz >= %{pytz_min_version}
Requires:       %{mypython}-robot-detection >= %{robot_detection_min_version}
Requires:       %{mypython}-xapian-haystack >= %{django_haystack_min_version}
# help in replacing any previously installed flavor package back to the unprefixed package
%if 0%{?suse_version} < 1550
Obsoletes:      python3-%{hyperkitty_pkgname} < %{version}-%{release}
%endif
Provides:       %{mypython}-%{hyperkitty_pkgname} = %{version}-%{release}
Obsoletes:      %{mypython}-%{hyperkitty_pkgname} < %{version}-%{release}
%if 0%{?suse_version} >= 1550
Requires:       sassc
%endif

%description -n %{hyperkitty_pkgname}
A web interface to access GNU Mailman v3 archives.

%package -n %{hyperkitty_pkgname}-web
Summary:        The webroot for GNU Mailman
Requires:       %{hyperkitty_pkgname}
Requires:       acl
Requires:       openssl
Requires:       sudo
Requires:       system-user-%{lowname}

%description -n %{hyperkitty_pkgname}-web
A web user interface for GNU Mailman.

This package holds the web interface.

%package -n %{hyperkitty_pkgname}-web-uwsgi
Summary:        HyperKitty - uwsgi configuration
Requires:       %{hyperkitty_pkgname}-web
%if 0%{suse_version} >= 1550 || 0%{?sle_version} >= 150500
Requires:       %{mypython}-uwsgi-python3
%else
Requires:       uwsgi-python3
%endif

%description -n %{hyperkitty_pkgname}-web-uwsgi
A web user interface for GNU Mailman.

This package holds the uwsgi configuration.

%package -n system-user-%{lowname}
Summary:        System user for HyperKitty
BuildArch:      noarch
BuildRequires:  sysuser-tools
%sysusers_requires

%description -n system-user-%{lowname}
System user for HyperKitty.

%prep
%setup -n hyperkitty-%{version}
cp %{SOURCE30} .
touch settings_local.py

# Copy example_project to just build the static files
rsync -a example_project/* build_static_files

%autopatch -p1

tee > %{lowname}.sysuser <<EOF
u %{lowname} - "HyperKitty" %{hyperkitty_basedir} -
EOF

%build
sed -i 's|^#!/usr/bin/env.*|#!%{__mypython}|' \
    example_project/manage.py
sed -i 's|/usr/bin/python3|%{__mypython}|' %{SOURCE10} %{SOURCE20} %{SOURCE21}
sed -i 's|python3|%{mypython}|' %{SOURCE12}

%pyproject_wheel

# Build static files
export PYTHONPATH=$(pwd)
%python_exec build_static_files/manage.py collectstatic --clear --noinput
%python_exec build_static_files/manage.py compress --force

%sysusers_generate_pre %{lowname}.sysuser %{lowname}

%install
install -d -m 0750 \
    %{buildroot}%{hyperkitty_etcdir} \
    %{buildroot}%{hyperkitty_libdir} \
    %{buildroot}%{hyperkitty_datadir} \
    %{buildroot}%{hyperkitty_datadir}/attachments \
    %{buildroot}%{hyperkitty_logdir}

install -d -m 0755 \
    %{buildroot}%{hyperkitty_basedir} \
    %{buildroot}%{hyperkitty_localedir} \
    %{buildroot}%{hyperkitty_staticdir} \
    %{buildroot}%{hyperkitty_staticdir}/CACHE \
    %{buildroot}%{_unitdir}

%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

# Copy static files
rsync -a build_static_files/static %{buildroot}%{hyperkitty_basedir}
# Remove the directory
%python_expand rm -rf %{buildroot}%{$python_sitelib}/build_static_files

rsync -a example_project/* %{buildroot}%{hyperkitty_basedir}
chmod -x %{buildroot}%{hyperkitty_basedir}/wsgi.py

for f in \
         README.rst \
         apache.conf \
         crontab \
         qcluster.service \
    ; do
    rm -f %{buildroot}%{hyperkitty_basedir}/$f
done
rm -f %{buildroot}%{hyperkitty_localedir}/.keep
rm -f %{buildroot}%{hyperkitty_basedir}/logs/.keep

%python_expand rm -rf %{buildroot}%{$python_sitelib}/example_project

# Create an empty settings_local.py. This will be filled with a SECRET_KEY in post
install -m 0644 settings_local.py %{buildroot}%{hyperkitty_etcdir}/settings_local.py

ln -svf %{hyperkitty_etcdir}/settings_local.py \
    %{buildroot}/%{hyperkitty_basedir}/settings_local.py

%fdupes %{buildroot}%{hyperkitty_basedir}

# Manage script
install -d -m 0755 %{buildroot}%{_sbindir}
install -m 0755 %{SOURCE10} %{buildroot}%{_sbindir}/hyperkitty-manage

install -d -m 0755 %{buildroot}%{_sysconfdir}/uwsgi/vassals
install -m 0644 %{SOURCE12} %{buildroot}%{_sysconfdir}/uwsgi/vassals/hyperkitty.ini

install -m 0644 %{SOURCE20} %{buildroot}%{_unitdir}/hyperkitty-qcluster.service
ln -s /sbin/service %{buildroot}%{_sbindir}/rchyperkitty-qcluster

for job in \
           minutely \
           quarter-hourly \
           hourly \
           daily \
           weekly \
           monthly \
           yearly \
           ; do
    install -m 0644 %{SOURCE21} %{buildroot}%{_unitdir}/hyperkitty-runjob-${job}.service
    sed -i "s/@HYPERKITTY_RUNJOB@/${job}/g" %{buildroot}%{_unitdir}/hyperkitty-runjob-${job}.service
    ln -s /sbin/service %{buildroot}%{_sbindir}/rchyperkitty-runjob-${job}

    install -m 0644 %{SOURCE22} %{buildroot}%{_unitdir}/hyperkitty-runjob-${job}.timer

    hyperkitty_runjob_calendar="OnCalendar=${job}"
    hyperkitty_runjob_delay="RandomizedDelaySec=15m"
    hyperkitty_runjob_name="${job}"

    if [ "${job}" = "minutely" ]; then
        hyperkitty_runjob_delay="RandomizedDelaySec=15s"
    elif [ "${job}" = "quarter-hourly" ]; then
        hyperkitty_runjob_calendar="OnCalendar=*:0/15"
        hyperkitty_runjob_delay="RandomizedDelaySec=2m"
        # The real jobname is with an underscore
        hyperkitty_runjob_name="quarter_hourly"
    fi
    sed -i "s#@HYPERKITTY_RUNJOB_CALENDAR@#${hyperkitty_runjob_calendar}#g" %{buildroot}%{_unitdir}/hyperkitty-runjob-${job}.timer
    sed -i "s#@HYPERKITTY_RUNJOB_DELAY@#${hyperkitty_runjob_delay}#g" %{buildroot}%{_unitdir}/hyperkitty-runjob-${job}.timer
    sed -i "s#@HYPERKITTY_RUNJOB@#${hyperkitty_runjob_name}#g" %{buildroot}%{_unitdir}/hyperkitty-runjob-${job}.timer
done

install -Dm644 %{lowname}.sysuser %{buildroot}%{_sysusersdir}/%{lowname}.conf

%if %{with testuite}
%check
export PYTHONPATH="$(pwd)"
export LANG=C.UTF-8
%pytest
%endif

%pre -n %{hyperkitty_pkgname}-web
%service_add_pre %{hyperkitty_services}

%pre -n system-user-%{lowname} -f %{lowname}.pre

%post -n %{hyperkitty_pkgname}-web
# We need a SECRET_KEY for manage to work
if ! grep -q "^SECRET_KEY.*" %{hyperkitty_etcdir}/settings_local.py; then
    echo "SECRET_KEY='$(openssl rand -base64 48)'" >> %{hyperkitty_etcdir}/settings_local.py
fi
%{_sbindir}/hyperkitty-manage makemigrations --pythonpath /srv/www/webapps/mailman/hyperkitty/ --settings settings
%{_sbindir}/hyperkitty-manage migrate --pythonpath /srv/www/webapps/mailman/hyperkitty/ --settings settings

%service_add_post %{hyperkitty_services}

%preun -n %{hyperkitty_pkgname}-web
%service_del_preun %{hyperkitty_services}

%postun -n %{hyperkitty_pkgname}-web
%service_del_postun %{hyperkitty_services}

%files -n %{hyperkitty_pkgname}
%doc AUTHORS.txt README.rst example_project
%license COPYING.txt
%{mypython_sitelib}/hyperkitty
%{mypython_sitelib}/hyperkitty-%{version}*-info

%files -n %{hyperkitty_pkgname}-web
%doc README.SUSE.md
%{_sbindir}/hyperkitty-manage
%{_sbindir}/rchyperkitty-qcluster
%{_sbindir}/rchyperkitty-runjob-*
%dir %{webapps_dir}
%dir %{webapps_dir}/mailman
%{_unitdir}/hyperkitty-qcluster.service
%{_unitdir}/hyperkitty-runjob-*.service
%{_unitdir}/hyperkitty-runjob-*.timer

%defattr(-,root,hyperkitty)
%dir %{hyperkitty_basedir}
%{hyperkitty_basedir}/__init__.py
%{hyperkitty_basedir}/manage.py
%{hyperkitty_basedir}/settings.py
%{hyperkitty_basedir}/settings_local.py
%{hyperkitty_basedir}/urls.py
%{hyperkitty_basedir}/wsgi.py

%dir %{hyperkitty_basedir}/static
%{hyperkitty_basedir}/static/admin
%{hyperkitty_basedir}/static/debug_toolbar
%{hyperkitty_basedir}/static/django-mailman3
%{hyperkitty_basedir}/static/django_extensions
%{hyperkitty_basedir}/static/hyperkitty
%{hyperkitty_basedir}/static/rest_framework

# The wsgi needs to write to static/CACHE
%attr(755,hyperkitty,hyperkitty) %dir %{hyperkitty_basedir}/static/CACHE
%attr(644,hyperkitty,hyperkitty) %{hyperkitty_basedir}/static/CACHE/manifest.json

%attr(755,hyperkitty,hyperkitty) %dir %{hyperkitty_basedir}/static/CACHE/css
%attr(644,hyperkitty,hyperkitty) %{hyperkitty_basedir}/static/CACHE/css/output.*.css

%attr(755,hyperkitty,hyperkitty) %dir %{hyperkitty_basedir}/static/CACHE/js
%attr(644,hyperkitty,hyperkitty) %{hyperkitty_basedir}/static/CACHE/js/output.*.js

%dir %{hyperkitty_localedir}

%attr(750,root,hyperkitty) %dir %{hyperkitty_etcdir}
%attr(640,root,hyperkitty) %config(noreplace) %{hyperkitty_etcdir}/settings_local.py
%attr(750,root,hyperkitty) %dir %{hyperkitty_libdir}
%attr(750,hyperkitty,hyperkitty) %dir %{hyperkitty_datadir}
%attr(770,hyperkitty,hyperkitty) %dir %{hyperkitty_logdir}

%files -n %{hyperkitty_pkgname}-web-uwsgi
%dir %{_sysconfdir}/uwsgi
%dir %{_sysconfdir}/uwsgi/vassals
%config (noreplace) %{_sysconfdir}/uwsgi/vassals/hyperkitty.ini

%files -n system-user-%{lowname}
%{_sysusersdir}/%{lowname}.conf

%changelog
* Sat Mar  2 2024 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.3.9
  * https://gitlab.com/mailman/hyperkitty/-/releases/1.3.9
- Removed mistune3.patch
* Thu Feb 29 2024 Ben Greiner <code@bnavigator.de>
- Simplify python flavor selection
  * Go back to primary python3 on Tumbleweed
  * Use SLE15 python module pythons on 15.x
- Build PEP517 wheel
* Wed Feb 28 2024 Andreas Schneider <asn@cryptomilk.org>
- Fix building on SLE15 based distributions
* Sat Feb 24 2024 Georg Pfuetzenreuter <mail+rpm@georg-pfuetzenreuter.net>
- Split out system user
* Fri Feb 23 2024 Georg Pfuetzenreuter <mail+rpm@georg-pfuetzenreuter.net>
- Build for Python 3.12
* Mon Nov  6 2023 Marcus Rueckert <mrueckert@suse.de>
- forgot to use 2 defined variables:
  %%{django_haystack_min_version}
  %%{django_extensions_min_version}
* Mon Nov  6 2023 Marcus Rueckert <mrueckert@suse.de>
- make it easy to run a build without testsuite
  osc build --without=testsuite
* Mon Nov  6 2023 Marcus Rueckert <mrueckert@suse.de>
- ensure that we can create the user and group
* Mon Nov  6 2023 Marcus Rueckert <mrueckert@suse.de>
- make user and group creation verbose so we actually see errors
* Mon Nov  6 2023 Marcus Rueckert <mrueckert@suse.de>
- make it easier to notice to keep buildrequires and runtime
  requires version limits in sync. This will also help us to notice
  early when the version of other libraries do not match the
  requires encoded in the source code.
* Sun Nov  5 2023 Marcus Rueckert <mrueckert@suse.de>
- refresh gl-mr300-add-opengraph-metadata.patch for version update
* Thu Nov  2 2023 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.3.8
  * See https://gitlab.com/mailman/hyperkitty/-/blob/v1.3.8/doc/news.rst
    or the file news.ret included in this package
- Removed fix-elasticsearch8.patch
- Updated mistune3.patch
* Thu Oct  5 2023 Markéta Machová <mmachova@suse.com>
- Add mistune3.patch to fix compatibility with mistune 3.0
* Sun Jul 30 2023 Georg Pfuetzenreuter <georg.pfuetzenreuter@suse.com>
- Add upstream patch gl-mr300-add-opengraph-metadata.patch:
  * Add OpenGraph Metadata (https://gitlab.com/mailman/hyperkitty/-/merge_requests/300)
- Add upstream patch gl-mr470-introduce-feed-filtering.patch:
  * Introduce feed filtering (https://gitlab.com/mailman/hyperkitty/-/merge_requests/470)
* Thu Jul  6 2023 Andreas Schneider <asn@cryptomilk.org>
- Add missing dependency to whoosh
* Sun Jul  2 2023 Andreas Schneider <asn@cryptomilk.org>
- Fix uwsgi requirement
* Sat Jul  1 2023 Andreas Schneider <asn@cryptomilk.org>
- Use sle15_python_module_pythons
- Some spec file fixes
* Sat Jul  1 2023 Andreas Schneider <asn@cryptomilk.org>
- Add BuildRequires for sassc
* Sun Jun 18 2023 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.3.7
  * ``hyperkitty_import`` will now import messages to a list with archiving
    disabled.  (Closes #451)
  * Add support for Python 3.11.
- Use sle15_python_module_pythons
* Wed Apr  5 2023 Andreas Schneider <asn@cryptomilk.org>
- Add missing requires for sassc used by manage.py
* Mon Nov 21 2022 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.3.6
  * Fixed an issue in hyperkitty_import with an empty Message-ID. (Closes #396)
  * Set Q_CLUSTER retry > timeout in example_project. (Closes #402)
  * Set DEFAULT_AUTO_FIELD to silence errors with Django >= 3.2.
  * Require mistune >= 2.0.0 and fix a problem with importing from it. (Closes
    [#395])
  * Adapt parsing of emails to be compatible with python 3.10. (Closes #401)
  * Add gitlab-ci integration for python 3.10.
  * Skip lists with private archives in the find list search. (Closes #237)
  * Add a new setting HYPERKITTY_MBOX_EXPORT which, when set to false, removes
    the :guilabel:`Download` button and disables the export view. ( Fixes #386)
  * Return 400 instead of 500 when the sort mode is invalid. (Fixes #270)
  * Allow HyperKitty to find attachments in either the database or the
    HYPERKITTY_ATTACHMENT_FOLDER. (Closes #213)
  * Implemented a new attachments_to_file management command to move attachment
    content to the file system after setting HYPERKITTY_ATTACHMENT_FOLDER.
    (Closes #413)
  * Handle exception when a banned address tries to post. (Fixes #325)
  * Add an index on the 'name' column (fqdn)for the MailingList table since it
    is most frequently used to query the MailingList object.
  * Add the ability to view a thread without Javascript enabled. This uses the
    same mechanism we use with bot-detection and rendering of the entire page
    at once, which will be slow to load but allow reading. (See #422)
  * Improve the performance of the thread view for logged-in users by
    optimizing the total database calls made. (See !409)
  * Add support for Django <= 4.1
  * Remove support for Django < 3.2
  * Remove support for Python 3.6
  * Fix tests to be compatible with Python 3.10
  * Replace use of mock with unittest.mock in all tests. (Closes #429)
  * The check for writability of HYPERKITTY_ATTACHMENT_FOLDER when set has been
    improved to avoid a potential race condition. (Closes #389)
- Run complete testsuite with pytest
- Removed hyperkitty-django4.patch
- Removed hyperkitty-fix-mistune-2.0-imports.patch
- Removed python-HyperKitty-no-mock.patch
- Removed hyperkitty-fix-qcluster-timeout.patch
- Removed hyperkitty-fix-py310-tests.patch
- Removed fix-django41.patch
* Thu Oct  6 2022 Daniel Garcia <daniel.garcia@suse.com>
- Add fix-django41.patch to fix issues with django4.1
- Add fix-elasticsearch8.patch to fix issues with elasticsearch 8.0.0
* Mon Jul  4 2022 Ben Greiner <code@bnavigator.de>
- Rename the built package to python prefixless HyperKitty
  * Doesn't imply any false impression of multiflavor
- Go back to python39 -- highest supported Python by mailman
* Sun Jul  3 2022 Ben Greiner <code@bnavigator.de>
- Add hyperkitty-fix-py310-tests.patch
  * Fix test failures on Python 3.10 (and Python 3.9.13)
  * https://gitlab.com/mailman/hyperkitty/-/issues/401
  * https://gitlab.com/mailman/hyperkitty/-/merge_requests/381
  * https://gitlab.com/mailman/hyperkitty/-/merge_requests/449
* Sat Jul  2 2022 Andreas Schneider <asn@cryptomilk.org>
- Fix django warning that timeout is bigger than retry
  * Added hyperkitty-fix-qcluster-timeout.patch
* Fri Jun 10 2022 Andreas Schneider <asn@cryptomilk.org>
- First Make migrations on update, then call migrate
* Thu May 26 2022 pgajdos@suse.com
- do not require python-mock for build
- added patches
  fix https://gitlab.com/mailman/hyperkitty/-/issues/429
  + python-HyperKitty-no-mock.patch
* Tue Dec 28 2021 John Vandenberg <jayvdb@gmail.com>
- Add hyperkitty-django4.patch to support Django 4
* Fri Dec 17 2021 Matej Cepl <mcepl@suse.com>
- Add hyperkitty-fix-mistune-2.0-imports.patch ... two function
  moved in mistune 2.0 (gl#mailman/hyperkitty#379).
* Thu Dec 16 2021 Sasi Olin <hel@lcp.world>
- Add a patch that fixes compatibility with the full release of mistune 2.0
* Wed Nov 17 2021 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.3.5
  * https://gitlab.com/mailman/hyperkitty/-/blob/1.3.5/doc/news.rst
- Fixes CVE-2021-35057
- Removed obsolete python-HyperKitty-CVE-2021-33038.patch
* Wed Jun  2 2021 Andreas Schneider <asn@cryptomilk.org>
- Fix log dir permissions
* Wed Jun  2 2021 pgajdos@suse.com
- security update
- added patches
  fix CVE-2021-33038 [bsc#1186575], information disclosure when importing a private mailing list
  + python-HyperKitty-CVE-2021-33038.patch
* Wed May 26 2021 Andreas Schneider <asn@cryptomilk.org>
- Remove the hyperkitty-admin user
* Tue May 25 2021 Andreas Schneider <asn@cryptomilk.org>
- Create static files as part of the build process
- Fixed CVE-2021-25322
* Tue May  4 2021 Ben Greiner <code@bnavigator.de>
- restrict to primary python3 flavor due to mailman
* Wed Feb  3 2021 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.3.4
  * Sync owners and moderators from Mailman Core for MailingList. (Fixes #302)
  * Implemented a new HYPERKITTY_JOBS_UPDATE_INDEX_LOCK_LIFE setting to set the
    lock lifetime for the update_and_clean_index job. (Closes #300)
  * Implemented a new HYPERKITTY_ALLOW_WEB_POSTING that allows disabling the
    web posting feature. (Closes #264)
  * Add the ability to disable Gravatar using HYPERKITTY_ENABLE_GRAVATAR
    settings. (Closes #303)
  * Replaced deprecated ugettext functions with gettext. (Closes #310)
  * Fix export of Email message where the In-Reply-To header doesn’t include
    the <> brackets. (Closes #331)
  * We now catch a few more exceptions in hyperkitty_import when getting
    messages from a mbox. (Closes #313 and #314)
  * Added a new contrib/check_hk_import script to check mboxes before running
    hyperkitty_import.
  * We now ignore a ValueError in hyperkitty_import when trying to replace a
    Subject: header. (Closes #317)
  * hyperkitty_import now includes the mbox name in error messages when
    importing multiple mboxes. (Closes #318)
  * `` at `` is now only replaced with @ in From: header values when necessary
    and not unconditionally. (Closes #320)
  * The wildcard notation for any host '*' is now supported into
    MAILMAN_ARCHVER_FROM to disable Hyperkitty clients IP checking.
  * Join the searchbar and search button like it was before bootstrap 4
    migration. (See !301)
  * Use the umd builds for popper.js instead of the regular ones. (See !309)
  * Exceptions thrown by smtplib in sending replies are now caught and give an
    appropriate error message. (Closes #309)
- Removed hyperkitty-fix-tests.patch
- Fixed build on tumbleweed
* Mon Dec 28 2020 Andreas Schneider <asn@cryptomilk.org>
- Fix quarter hourly timer
* Sun Dec 20 2020 Andreas Schneider <asn@cryptomilk.org>
- Fix access to CACHE dir
- Improve documentation (README.SUSE.md)
- Fix quaterly timer and service
* Sun Dec 13 2020 Andreas Schneider <asn@cryptomilk.org>
- Added hyperkitty-qcluster.service
- Added hyperkitty-runjob.service and hyperkitty-runjob.timer
* Sat Dec 12 2020 Andreas Schneider <asn@cryptomilk.org>
- Create a HyperKitty-web package with webroot files
- Create a HyperKitty-web-uwsgi with uwsgi configuration
- Added hyperkitty-settings.patch
  * Sets the FHS default paths
- Added hyperkitty-fix-tests.patch
  * Make migration compatible with django >= 3.1
- Added rpmlint config
* Tue Aug  4 2020 Stasiek Michalski <stasiek@michalski.cc>
- Version update to 1.3.3
  * Allow SHOW_INACTIVE_LISTS_DEFAULT setting to be configurable. (Closes #276)
  * Fix a bug where the user couldn’t chose the address to send reply or new post as. (Closes #288)
  * Improve the Django admin command reference from hyperkitty_import. (Closes #281)
  * Fix FILTER_VHOST to work with web hosts other than the email host. (Closes #254)
  * Fixed a bug where export can fail if certain headers are wrapped. (Closes #292)
  * Fixed hyperkitty_import to allow odd line endings in a folded message subject. (Closes #280)
  * Fixed a bug that could throw an IndexError when exporting messages. (Closes #293)
  * Use errors='replace' when encoding attachments. (Closes #294)
- Drop merged python-HyperKitty-remove-legacy-use-of-available_attrs.patch
* Thu May 14 2020 pgajdos@suse.com
- version update to 1.3.2
  - Remove support for Django 1.11. (Closes #273)
  - Skip ``Thread.DoesNotExist`` exception when raised within
    ``rebuild_thread_cache_votes``. (Closes #245)
  - Send 400 status code for ``ValueError`` when archiving. (Closes #271)
  - Fix a bug where exception for elasticsearch backend would not be caught. (Closes #263)
- added patches
  https://gitlab.com/mailman/hyperkitty/-/commit/03c99ad5beefeac4474b5a00c840fd9debccba02
  + python-HyperKitty-remove-legacy-use-of-available_attrs.patch
* Fri Jan 10 2020 pgajdos@suse.com
- fix dependency (django_compressor -> django-compressor)
* Tue Dec 10 2019 pgajdos@suse.com
- version update to 1.3.1
  * Add support to delete mailing list. (Closes #3)
  * Fix a bug where messages with attachments would skip adding the body when
    exporting the email. (Closes #252)
  * Fix a bug where exporting mbox with messages that have attachments saved
    to disk would raise exception and return a corrupt mbox. (Closes #258)
  * Fix a bug where downloaded attachments are returned as a memoryview object
    instead of bytes and hence fail to download. (Closes #247)
  * Fix a bug where migrations would fail with exceptions on postgresl. (Closes
    [#266])
  * Add support for Django 3.0.
* Mon Dec  2 2019 pgajdos@suse.com
- call spec-cleaner
* Wed Nov 27 2019 pgajdos@suse.com
- package documentation
* Wed Nov 27 2019 pgajdos@suse.com
- require python-libsass
* Thu Nov 14 2019 pgajdos@suse.com
- run the testsuite correctly
* Tue Oct  1 2019 pgajdos@suse.com
- initial version 1.3.0 [SLE-7686]
